#!/bin/bash
set -o errexit
set -o nounset
set -o pipefail

# install required packages
sudo apt update > /dev/null 2>&1
sudo apt install -y -q=3 gcc libffi-dev libssl-dev lsb-release libpython3-dev \
    python3-minimal python3-pip python3-yaml virtualenv

# workaround for https://github.com/pypa/virtualenv/issues/1029
export PS1=${PS1:-}

cd $WORKSPACE
echo "Info: Installing OpenStack Jenkins Job Builder (JJB) version $JJB_VERSION from source in venv"
echo "----------------------------------------------------"
git clone -q $JJB_GIT_REPO -b $JJB_VERSION > /dev/null 2>&1
virtualenv -p python3 --quiet --no-site-packages .venv
source .venv/bin/activate
cd jenkins-job-builder && pip install -q -r test-requirements.txt -e .
echo "Info: Installed JJB"
jenkins-jobs --version
echo "----------------------------------------------------"
echo "Info: Proceeding with job updates"
echo "----------------------------------------------------"
cd $WORKSPACE
jenkins-jobs --conf jjb/global/jenkins_jobs.ini --user $JJB_USERNAME --password $JJB_USERTOKEN \
    update --recursive --delete-old --workers 4 jjb/
echo "----------------------------------------------------"
echo "Info: Done"
